==> haskell-hspec-meta-2.4.6-13-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-hspec-meta.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: hspec-meta
version: 2.4.6
id: hspec-meta-2.4.6-KsYQM4iIMwrKbWYQlqi8gW
key: hspec-meta-2.4.6-KsYQM4iIMwrKbWYQlqi8gW
license: MIT
copyright: (c) 2011-2017 Simon Hengel,
           (c) 2011-2012 Trystan Spangler,
           (c) 2011 Greg Weber
maintainer: Simon Hengel <sol@typeful.net>
stability: experimental
homepage: http://hspec.github.io/
synopsis: A version of Hspec which is used to test Hspec itself
description:
    A stable version of Hspec which is used to test the
    in-development version of Hspec.
category: Testing
abi: b0c80acfb9aaae92ab7b4ec4d7a911c2
exposed: True
exposed-modules:
    Test.Hspec.Meta
hidden-modules: Test.Hspec Test.Hspec.Core Test.Hspec.Discover
                Test.Hspec.Formatters Test.Hspec.HUnit Test.Hspec.QuickCheck
                Test.Hspec.Runner Test.Hspec.Core.Compat Test.Hspec.Core.Config
                Test.Hspec.Core.Example Test.Hspec.Core.FailureReport
                Test.Hspec.Core.Formatters Test.Hspec.Core.Formatters.Diff
                Test.Hspec.Core.Formatters.Free Test.Hspec.Core.Formatters.Internal
                Test.Hspec.Core.Formatters.Monad Test.Hspec.Core.Hooks
                Test.Hspec.Core.Options Test.Hspec.Core.QuickCheck
                Test.Hspec.Core.QuickCheckUtil Test.Hspec.Core.Runner
                Test.Hspec.Core.Runner.Eval Test.Hspec.Core.Spec
                Test.Hspec.Core.Spec.Monad Test.Hspec.Core.Timer
                Test.Hspec.Core.Tree Test.Hspec.Core.Util Data.Algorithm.Diff
                Paths_hspec_meta
import-dirs: /usr/lib/ghc-8.4.3/site-local/hspec-meta-2.4.6
library-dirs: /usr/lib/ghc-8.4.3/site-local/hspec-meta-2.4.6
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/hspec-meta-2.4.6
hs-libraries: HShspec-meta-2.4.6-KsYQM4iIMwrKbWYQlqi8gW
depends:
    HUnit-1.6.0.0-8OmbxYW4AG9PppbZs26Xx
    QuickCheck-2.11.3-58QsvdIMmwDDNaUIIDmLAr
    ansi-terminal-0.8.1-72nCTUZRZdJG8ztHzhbgjc array-0.5.2.0
    async-2.2.1-B6m2kYywRJu7nicgTBxsJe base-4.11.1.0
    call-stack-0.1.0-Eiz5FM8yQXpI3vyQ1Rt4Jq deepseq-1.4.3.0
    directory-1.3.1.5 filepath-1.4.2
    hspec-expectations-0.8.2-CTUpAwnEHwLApugPfKahJk
    quickcheck-io-0.2.0-Ecz5aZHo1Ni4V43YDiqW58
    random-1.1-9LLJAJa4iQFLJiLXBOBXBV
    setenv-0.1.1.3-H1xmIqlPy4yIDquO6eJhBl time-1.8.0.2
    transformers-0.5.5.0
abi-depends: HUnit-1.6.0.0-8OmbxYW4AG9PppbZs26Xx=6ff9610fd5e59ec310c47074d0590847
             QuickCheck-2.11.3-58QsvdIMmwDDNaUIIDmLAr=59a035869ce3bae16d8c8360447f600f
             ansi-terminal-0.8.1-72nCTUZRZdJG8ztHzhbgjc=ac560d64fefa05d8067fac44b9aaa9de
             array-0.5.2.0=dc85b03ee806d784249cc791da6109c3
             async-2.2.1-B6m2kYywRJu7nicgTBxsJe=32776142fda961cc693aa4db742773f9
             base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             call-stack-0.1.0-Eiz5FM8yQXpI3vyQ1Rt4Jq=c76ca250c7cf6b5c2ee744c15760c93f
             deepseq-1.4.3.0=34da2d42d10eacba0aad99c95b538637
             directory-1.3.1.5=f5fa3aef63d61d9b32ef25d211ef137f
             filepath-1.4.2=2408ba322304c0a06810db2d7363214a
             hspec-expectations-0.8.2-CTUpAwnEHwLApugPfKahJk=b75babfddd4aa9a267b9714ea3ac9e19
             quickcheck-io-0.2.0-Ecz5aZHo1Ni4V43YDiqW58=391db9bfefe77ce03304f14e4733dc3c
             random-1.1-9LLJAJa4iQFLJiLXBOBXBV=2cade9e72fa19fe7a43e5ace84505d9f
             setenv-0.1.1.3-H1xmIqlPy4yIDquO6eJhBl=f590a47c94186759709b79b52a1e0710
             time-1.8.0.2=042930fb6746cbaf3bc794f817f8a6b2
             transformers-0.5.5.0=4f41484af13f560f1d83ed79e1be4572
haddock-interfaces: /usr/share/doc/haskell-hspec-meta/html/hspec-meta.haddock
haddock-html: /usr/share/doc/haskell-hspec-meta/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hspec-meta-2.4.6-14-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-hspec-meta.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: hspec-meta
version: 2.4.6
id: hspec-meta-2.4.6-fD0gh3wQMIDB5RAb5g65N
key: hspec-meta-2.4.6-fD0gh3wQMIDB5RAb5g65N
license: MIT
copyright: (c) 2011-2017 Simon Hengel,
           (c) 2011-2012 Trystan Spangler,
           (c) 2011 Greg Weber
maintainer: Simon Hengel <sol@typeful.net>
stability: experimental
homepage: http://hspec.github.io/
synopsis: A version of Hspec which is used to test Hspec itself
description:
    A stable version of Hspec which is used to test the
    in-development version of Hspec.
category: Testing
abi: f9d391d438931971e8c8d393e1d1bc91
exposed: True
exposed-modules:
    Test.Hspec.Meta
hidden-modules: Test.Hspec Test.Hspec.Core Test.Hspec.Discover
                Test.Hspec.Formatters Test.Hspec.HUnit Test.Hspec.QuickCheck
                Test.Hspec.Runner Test.Hspec.Core.Compat Test.Hspec.Core.Config
                Test.Hspec.Core.Example Test.Hspec.Core.FailureReport
                Test.Hspec.Core.Formatters Test.Hspec.Core.Formatters.Diff
                Test.Hspec.Core.Formatters.Free Test.Hspec.Core.Formatters.Internal
                Test.Hspec.Core.Formatters.Monad Test.Hspec.Core.Hooks
                Test.Hspec.Core.Options Test.Hspec.Core.QuickCheck
                Test.Hspec.Core.QuickCheckUtil Test.Hspec.Core.Runner
                Test.Hspec.Core.Runner.Eval Test.Hspec.Core.Spec
                Test.Hspec.Core.Spec.Monad Test.Hspec.Core.Timer
                Test.Hspec.Core.Tree Test.Hspec.Core.Util Data.Algorithm.Diff
                Paths_hspec_meta
import-dirs: /usr/lib/ghc-8.6.1/site-local/hspec-meta-2.4.6
library-dirs: /usr/lib/ghc-8.6.1/site-local/hspec-meta-2.4.6
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.6.1/hspec-meta-2.4.6
hs-libraries: HShspec-meta-2.4.6-fD0gh3wQMIDB5RAb5g65N
depends:
    HUnit-1.6.0.0-Kc3RXVOuMSQ9Y4PmNrdWEj
    QuickCheck-2.11.3-BDoyaQh2Mcq3pIdI4VETKc
    ansi-terminal-0.8.1-9jw961s99VhJdcOClGpOKt array-0.5.2.0
    async-2.2.1-GYH0rb5jjEHH7NChV9fWYh base-4.12.0.0
    call-stack-0.1.0-J1eWgTNOnM4IGVyeW0v2YZ deepseq-1.4.4.0
    directory-1.3.3.0 filepath-1.4.2.1
    hspec-expectations-0.8.2-EQolLGCe6il5TbRMQrSrzg
    quickcheck-io-0.2.0-K1CixCxBGnbAXXJEyFVI3w
    random-1.1-3ypV4EIycgb35PKjTYYr5q
    setenv-0.1.1.3-HP1VaXwIiC57fC12rF12pz time-1.8.0.2
    transformers-0.5.5.0
haddock-interfaces: /usr/share/doc/haskell-hspec-meta/html/hspec-meta.haddock
haddock-html: /usr/share/doc/haskell-hspec-meta/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
